@@ -746,6 +746,9 @@ class DescribeKTVRobotsRequest(AbstractModel):
 <li>Pause：暂停</li>
 <li>Destroy：销毁</li>
         :type Statuses: list of str
+        :param CreateTime: 匹配创建时间在此时间段内的机器人。
+<li>包含所指定的头尾时间点。</li>
+        :type CreateTime: :class:`tencentcloud.ame.v20190916.models.TimeRange`
         :param Offset: 分页返回的起始偏移量，默认值：0。将返回第 Offset 到第 Offset+Limit-1 条。
         :type Offset: int
         :param Limit: 分页返回的起始偏移量，默认值：10。
@@ -753,6 +756,7 @@ class DescribeKTVRobotsRequest(AbstractModel):
         """
         self.RobotIds = None
         self.Statuses = None
+        self.CreateTime = None
         self.Offset = None
         self.Limit = None
 
@@ -760,6 +764,9 @@ class DescribeKTVRobotsRequest(AbstractModel):
     def _deserialize(self, params):
         self.RobotIds = params.get("RobotIds")
         self.Statuses = params.get("Statuses")
+        if params.get("CreateTime") is not None:
+            self.CreateTime = TimeRange()
+            self.CreateTime._deserialize(params.get("CreateTime"))
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
         memeber_set = set(params.keys())
@@ -1514,6 +1521,12 @@ class KTVRobotInfo(AbstractModel):
         :param RTCSystem: RTC厂商类型，取值有：
 <li>TRTC</li>
         :type RTCSystem: str
+        :param SetPlayModeInput: 播放模式，PlayMode取值有：
+<li>RepeatPlaylist：列表循环</li>
+<li>Order：顺序播放</li>
+<li>RepeatSingle：单曲循环</li>
+<li>Shuffle：随机播放</li>
+        :type SetPlayModeInput: :class:`tencentcloud.ame.v20190916.models.SetPlayModeCommandInput`
         """
         self.RobotId = None
         self.Status = None
@@ -1523,6 +1536,7 @@ class KTVRobotInfo(AbstractModel):
         self.SetAudioParamInput = None
         self.JoinRoomInput = None
         self.RTCSystem = None
+        self.SetPlayModeInput = None
 
 
     def _deserialize(self, params):
@@ -1538,6 +1552,9 @@ class KTVRobotInfo(AbstractModel):
             self.JoinRoomInput = JoinRoomInput()
             self.JoinRoomInput._deserialize(params.get("JoinRoomInput"))
         self.RTCSystem = params.get("RTCSystem")
+        if params.get("SetPlayModeInput") is not None:
+            self.SetPlayModeInput = SetPlayModeCommandInput()
+            self.SetPlayModeInput._deserialize(params.get("SetPlayModeInput"))
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -2276,6 +2293,34 @@ class SetAudioParamCommandInput(AbstractModel):
         
 
 
+class SetPlayModeCommandInput(AbstractModel):
+    """设置播放模式
+
+    """
+
+    def __init__(self):
+        r"""
+        :param PlayMode: 播放模式，取值有：
+<li>RepeatPlaylist：列表循环</li>
+<li>Order：顺序播放</li>
+<li>RepeatSingle：单曲循环</li>
+<li>Shuffle：随机播放</li>
+        :type PlayMode: str
+        """
+        self.PlayMode = None
+
+
+    def _deserialize(self, params):
+        self.PlayMode = params.get("PlayMode")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class SetPlaylistCommandInput(AbstractModel):
     """设置播放列表指令参数
 
@@ -2375,6 +2420,7 @@ class SyncKTVRobotCommandRequest(AbstractModel):
 <li>Pause：暂停</li>
 <li>SwitchPrevious：上一首</li>
 <li>SwitchNext：下一首</li>
+<li>SetPlayMode：设置播放模式</li>
 <li>Seek：调整播放进度</li>
 <li>SetPlaylist：歌单变更</li>
 <li>SetAudioParam：音频参数变更</li>
@@ -2390,6 +2436,8 @@ class SyncKTVRobotCommandRequest(AbstractModel):
         :type SetAudioParamCommandInput: :class:`tencentcloud.ame.v20190916.models.SetAudioParamCommandInput`
         :param SendMessageCommandInput: 自定义消息，当Command取SendMessage时，必填。
         :type SendMessageCommandInput: :class:`tencentcloud.ame.v20190916.models.SendMessageCommandInput`
+        :param SetPlayModeCommandInput: 播放模式，当Command取SetPlayMode时，必填。
+        :type SetPlayModeCommandInput: :class:`tencentcloud.ame.v20190916.models.SetPlayModeCommandInput`
         """
         self.RobotId = None
         self.Command = None
@@ -2398,6 +2446,7 @@ class SyncKTVRobotCommandRequest(AbstractModel):
         self.SeekCommandInput = None
         self.SetAudioParamCommandInput = None
         self.SendMessageCommandInput = None
+        self.SetPlayModeCommandInput = None
 
 
     def _deserialize(self, params):
@@ -2418,6 +2467,9 @@ class SyncKTVRobotCommandRequest(AbstractModel):
         if params.get("SendMessageCommandInput") is not None:
             self.SendMessageCommandInput = SendMessageCommandInput()
             self.SendMessageCommandInput._deserialize(params.get("SendMessageCommandInput"))
+        if params.get("SetPlayModeCommandInput") is not None:
+            self.SetPlayModeCommandInput = SetPlayModeCommandInput()
+            self.SetPlayModeCommandInput._deserialize(params.get("SetPlayModeCommandInput"))
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -2568,6 +2620,36 @@ class TakeMusicOffShelvesResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class TimeRange(AbstractModel):
+    """时间范围
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Before: <li>大于等于此时间（起始时间）。</li>
+<li>格式按照 ISO 8601标准表示，详见 <a href="https://cloud.tencent.com/document/product/266/11732#I" target="_blank">ISO 日期格式说明</a>。</li>
+        :type Before: str
+        :param After: <li>小于此时间（结束时间）。</li>
+<li>格式按照 ISO 8601标准表示，详见 <a href="https://cloud.tencent.com/document/product/266/11732#I" target="_blank">ISO 日期格式说明</a>。</li>
+        :type After: str
+        """
+        self.Before = None
+        self.After = None
+
+
+    def _deserialize(self, params):
+        self.Before = params.get("Before")
+        self.After = params.get("After")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class UseRange(AbstractModel):
     """曲库包用途信息
 
